fn build_codec<'a>(
rows: impl IntoIterator<Item = &'a Row>,
) -> Option<ColumnsCodec>Expand description
Gather encoding statistics across rows and produce a codec from them.
Returns None when dictionary compression is disabled.
fn build_codec<'a>(
rows: impl IntoIterator<Item = &'a Row>,
) -> Option<ColumnsCodec>Gather encoding statistics across rows and produce a codec from them.
Returns None when dictionary compression is disabled.